import { GetOptions } from "infisical-node/lib/types/InfisicalClient";
import { createInfisicalClient } from "utils";

export let PROXY_SECRET: string;

// InfluxDB
export let INFLUXDB_URL: string;
export let INFLUXDB_ORG: string;
export let INFLUXDB_BUCKET: string;
export let INFLUXDB_TOKEN: string;

// MongoDB
export let MONGO_URI: string;

/**
 * Initialize the secrets from Infisical
 */
export async function initSecrets(token: string) {
  console.log("Initializing secrets...");

  const infisicalClient = createInfisicalClient(token);
  const options: GetOptions = {
    environment: process.env.NODE_ENV === "production" ? "main" : "dev",
    path: "/",
    type: "shared",
  };

  const proxySecret = (await infisicalClient.getSecret("PROXY_SECRET", options))
    .secretValue;

  // InfluxDB
  const influxDBUrl = (await infisicalClient.getSecret("INFLUXDB_URL", options))
    .secretValue;
  const influxDBOrg = (await infisicalClient.getSecret("INFLUXDB_ORG", options))
    .secretValue;
  const influxDBBucket = (
    await infisicalClient.getSecret("INFLUXDB_BUCKET", options)
  ).secretValue;
  const influxDBToken = (
    await infisicalClient.getSecret("INFLUXDB_TOKEN", options)
  ).secretValue;

  // Mongo
  const mongoUri = (await infisicalClient.getSecret("MONGO_URI", options))
    .secretValue;

  if (!proxySecret) {
    throw new Error("PROXY_SECRET not set in Infisical");
  }

  // InfluxDB
  if (!influxDBUrl) {
    throw new Error("INFLUXDB_URL not set in Infisical");
  }
  if (!influxDBOrg) {
    throw new Error("INFLUXDB_ORG not set in Infisical");
  }
  if (!influxDBBucket) {
    throw new Error("INFLUXDB_BUCKET not set in Infisical");
  }
  if (!influxDBToken) {
    throw new Error("INFLUXDB_TOKEN not set in Infisical");
  }

  // Mongo
  if (!mongoUri) {
    throw new Error("MONGO_URI not set in Infisical");
  }

  PROXY_SECRET = proxySecret;

  // InfluxDB
  INFLUXDB_URL = influxDBUrl;
  INFLUXDB_ORG = influxDBOrg;
  INFLUXDB_BUCKET = influxDBBucket;
  INFLUXDB_TOKEN = influxDBToken;

  // Mongo
  MONGO_URI = mongoUri;
}
